@@ -14,6 +14,7 @@ from regexapp.collection import PatternReference
 from regexapp import version
 from regexapp import edition
 from regexapp.core import enclose_string
+from regexapp import PatternBuilder
 
 import yaml
 import re
@@ -117,7 +118,7 @@ class Data:
     license_url = path.join(repo_url, 'blob/main/LICENSE')
     # TODO: Need to update wiki page for documentation_url instead of README.md.
     documentation_url = path.join(repo_url, 'blob/develop/README.md')
-    copyright_text = 'Copyright @ 2021 Geeks Trident LLC.  All rights reserved.'
+    copyright_text = 'Copyright @ 2021-2030 Geeks Trident LLC.  All rights reserved.'
 
     @classmethod
     def get_license(cls):
@@ -165,16 +166,25 @@ class Application:
 
     panedwindow (ttk.Panedwindow): a panedwindow for main layout.
     text_frame (ttk.Frame): a frame to contain test data component.
-    entry_frame (tk.Frame): a frame to contain any action button such as
+    entry_frame (ttk.Frame): a frame to contain any action button such as
             open, paste, build, snippet, unittest, pytest, ...
-    result_frame (tk.Frame): a frame to contain test result component.
+    result_frame (ttk.Frame): a frame to contain test result component.
+    var_name_frame (ttk.Frame): a frame to contain var_name textbox
+    word_bound_frame (ttk.Frame): a frame to contain word_bound combobox
     save_as_btn (ttk.Button): a Save As button.
     copy_text_btn (ttk.Button): a Copy Text button.
 
     test_data (str): a test data
+    snapshot (dict): store data of switching app.
 
     radio_line_or_multiline_btn_var (tk.StringVar): a variable for radio button
             Default is multiline.
+
+    builder_chkbox_var (tk.BooleanVar): a variable for builder checkbox.
+    var_name_var (tk.StringVar): a variable for var_name textbox.
+    word_bound_var (tk.StringVar): a variable for word_bound combobox.
+    is_confirmed (bool): True to show confirmation.  Default is True.
+
     prepended_ws_var (tk.BooleanVar): a variable for prepended_ws checkbox.
             Default is False
     appended_ws_var (tk.BooleanVar): a variable for appended_ws checkbox.
@@ -204,10 +214,17 @@ class Application:
     line_radio_btn (tk.RadioButton): a selection for enabling LinePattern.
     multiline_radio_btn (tk.RadioButton): a selection for enabling MultilinePattern.
 
+    Properties
+    ----------
+    is_pattern_builder_app -> bool
+
     Methods
     -------
+    shift_to_pattern_builder_app() -> None
+    shift_to_regex_builder_app() -> None
     get_pattern_args() -> dict
     get_builder_args() -> dict
+    get_pattern_builder_args() -> dict
     set_default_setting() -> None
     Application.get_textarea(node) -> str
     set_textarea(node, data, title='') -> None
@@ -241,13 +258,26 @@ class Application:
         self.text_frame = None
         self.entry_frame = None
         self.result_frame = None
+        self.var_name_frame = None
+        self.word_bound_frame = None
         self.save_as_btn = None
         self.copy_text_btn = None
+        self.snippet_btn = None
+        self.unittest_btn = None
+        self.pytest_btn = None
 
         self.test_data = None
+        self.snapshot = dict()
 
         self.radio_line_or_multiline_btn_var = tk.StringVar()
         self.radio_line_or_multiline_btn_var.set('multiline')
+
+        self.builder_chkbox_var = tk.BooleanVar()
+        self.var_name_var = tk.StringVar()
+        self.word_bound_var = tk.StringVar()
+        self.word_bound_var.set('none')
+        self.is_confirmed = True
+
         self.prepended_ws_var = tk.BooleanVar()
         self.appended_ws_var = tk.BooleanVar()
         self.ignore_case_var = tk.BooleanVar()
@@ -270,6 +300,20 @@ class Application:
         self.line_radio_btn = None
         self.multiline_radio_btn = None
 
+        self.is_macos = platform.system() == 'Darwin'
+        self.is_linux = platform.system() == 'Linux'
+        self.is_window = platform.system() == 'Windows'
+
+        self.RadioButton = tk.Radiobutton if self.is_linux else ttk.Radiobutton
+        self.CheckBox = tk.Checkbutton if self.is_linux else ttk.Checkbutton
+        self.Label = ttk.Label
+        self.Frame = ttk.Frame
+        self.LabelFrame = ttk.LabelFrame
+        self.Button = ttk.Button
+        self.TextBox = ttk.Entry
+        self.TextArea = tk.Text
+        self.PanedWindow = ttk.PanedWindow
+
         self.set_title()
         self.build_menu()
         self.build_frame()
@@ -277,6 +321,95 @@ class Application:
         self.build_entry()
         self.build_result()
 
+    @property
+    def is_pattern_builder_app(self):
+        return self.builder_chkbox_var.get() is True
+
+    def shift_to_pattern_builder_app(self):
+
+        if self.is_confirmed:
+            title = 'Switching To Pattern Builder App'
+            yesnocancel = """
+                Leaving Regex Builder App.
+                "Yes" will switch app and will show confirmation.
+                "No" will switch app and wont show confirmation.
+                "Cancel" wont switch app.
+                Do you want to switch app?
+            """
+            yesnocancel = dedent(yesnocancel).strip()
+            result = create_msgbox(title=title, yesnocancel=yesnocancel)
+            if result is None:
+                self.builder_chkbox_var.set(not self.builder_chkbox_var.get())
+            else:
+                self.is_confirmed = result
+        else:
+            result = self.is_confirmed
+
+        if result is not None:
+            data = self.get_textarea(self.textarea)
+            result = self.get_textarea(self.result_textarea)
+            self.snapshot.update(
+                dict(
+                    regex_builder_app_data=data,
+                    regex_builder_app_result=result
+                )
+            )
+            data = self.snapshot.get('pattern_builder_app_data', '')
+            result = self.snapshot.get('pattern_builder_app_result', '')
+
+            self.set_textarea(self.textarea, data)
+            self.set_textarea(self.result_textarea, result)
+
+            self.line_radio_btn.grid_remove()
+            self.multiline_radio_btn.grid_remove()
+            self.snippet_btn.grid_remove()
+            self.unittest_btn.grid_remove()
+            self.pytest_btn.grid_remove()
+            self.var_name_frame.grid(row=0, column=12)
+            self.word_bound_frame.grid(row=0, column=13)
+
+    def shift_to_regex_builder_app(self):
+        if self.is_confirmed:
+            title = 'Switching To Regex Builder App'
+            yesnocancel = """
+                Leaving Pattern Builder App.
+                "Yes" will switch app and will show confirmation.
+                "No" will switch app and wont show confirmation.
+                "Cancel" wont switch app.
+                Do you want to switch app?
+            """
+            yesnocancel = dedent(yesnocancel).strip()
+            result = create_msgbox(title=title, yesnocancel=yesnocancel)
+            if result is None:
+                self.builder_chkbox_var.set(not self.builder_chkbox_var.get())
+            else:
+                self.is_confirmed = result
+        else:
+            result = self.is_confirmed
+
+        if result is not None:
+            data = self.get_textarea(self.textarea)
+            result = self.get_textarea(self.result_textarea)
+            self.snapshot.update(
+                dict(
+                    pattern_builder_app_data=data,
+                    pattern_builder_app_result=result
+                )
+            )
+            data = self.snapshot.get('regex_builder_app_data', '')
+            result = self.snapshot.get('regex_builder_app_result', '')
+
+            self.set_textarea(self.textarea, data)
+            self.set_textarea(self.result_textarea, result)
+
+            self.line_radio_btn.grid(row=0, column=0, padx=(4, 0))
+            self.multiline_radio_btn.grid(row=0, column=1, padx=2)
+            self.snippet_btn.grid(row=0, column=8, pady=2)
+            self.unittest_btn.grid(row=0, column=9, pady=2)
+            self.pytest_btn.grid(row=0, column=10, pady=2)
+            self.var_name_frame.grid_remove()
+            self.word_bound_frame.grid_remove()
+
     def get_pattern_args(self):
         """return arguments of RegexBuilder class"""
         result = dict(
@@ -301,6 +434,16 @@ class Application:
         )
         return result
 
+    def get_pattern_builder_args(self):
+        """return arguments of PatternBuilder class"""
+        table = dict(none='', both='word_bound',
+                     left='word_bound_left', right='word_bound_right')
+        result = dict(
+            var_name=self.var_name_var.get(),
+            word_bound=table.get(self.word_bound_var.get(), '')
+        )
+        return result
+
     def set_default_setting(self):
         """reset to default setting"""
         self.prepended_ws_var.set(False)
@@ -376,7 +519,8 @@ class Application:
         if filename:
             with open(filename) as stream:
                 content = stream.read()
-                self.test_data = content
+                if not self.is_pattern_builder_app:
+                    self.test_data = content
                 self.set_textarea(self.textarea, content, title=filename)
 
     def callback_help_documentation(self):
@@ -400,34 +544,38 @@ class Application:
         def mouse_press(event):     # noqa
             self.browser.open_new_tab(url_lbl.link)
 
-        is_macos = platform.system() == 'Darwin'
-
         about = tk.Toplevel(self.root)
         self.set_title(node=about, title='About')
-        width, height = 400, 400
+        width, height = 440, 400
         x, y = get_relative_center_location(self.root, width, height)
         about.geometry('{}x{}+{}+{}'.format(width, height, x, y))
         about.resizable(False, False)
 
-        panedwindow = ttk.Panedwindow(about, orient=tk.VERTICAL)
+        top_frame = self.Frame(about)
+        top_frame.pack(fill=tk.BOTH, expand=True)
+
+        panedwindow = self.PanedWindow(top_frame, orient=tk.VERTICAL)
         panedwindow.pack(fill=tk.BOTH, expand=True, padx=8, pady=12)
 
         # company
-        frame = tk.Frame(panedwindow, width=380, height=20)
+        frame = self.Frame(panedwindow, width=420, height=20)
         panedwindow.add(frame, weight=1)
 
         fmt = 'Regex GUI v{} ({} Edition)'
-        company_lbl = tk.Label(frame, text=fmt.format(version, edition))
+        company_lbl = self.Label(frame, text=fmt.format(version, edition))
         company_lbl.pack(side=tk.LEFT)
 
         # URL
-        frame = tk.Frame(panedwindow, width=380, height=20)
+        frame = self.Frame(panedwindow, width=420, height=20)
         panedwindow.add(frame, weight=1)
 
         url = Data.repo_url
-        tk.Label(frame, text='URL:').pack(side=tk.LEFT)
-        font_size = 12 if is_macos else 10
-        url_lbl = tk.Label(frame, text=url, fg='blue', font=('sans-serif', font_size))
+        self.Label(frame, text='URL:').pack(side=tk.LEFT)
+        font_size = 12 if self.is_macos else 10
+        style = ttk.Style()
+        style.configure("Blue.TLabel", foreground="blue")
+        url_lbl = self.Label(frame, text=url, font=('sans-serif', font_size))
+        url_lbl.config(style='Blue.TLabel')
         url_lbl.default_font = ('sans-serif', font_size)
         url_lbl.pack(side=tk.LEFT)
         url_lbl.link = url
@@ -437,15 +585,15 @@ class Application:
         url_lbl.bind('<Button-1>', mouse_press)
 
         # license textbox
-        lframe = ttk.LabelFrame(
-            panedwindow, height=300, width=380,
+        lframe = self.LabelFrame(
+            panedwindow, height=300, width=420,
             text=Data.license_name
         )
         panedwindow.add(lframe, weight=7)
 
-        width = 49 if is_macos else 43
-        height = 19 if is_macos else 15
-        txtbox = tk.Text(lframe, width=width, height=height, wrap='word')
+        width = 55 if self.is_macos else 48
+        height = 19 if self.is_macos else 15 if self.is_linux else 16
+        txtbox = self.TextArea(lframe, width=width, height=height, wrap='word')
         txtbox.grid(row=0, column=0, padx=5, pady=5)
         scrollbar = ttk.Scrollbar(lframe, orient=tk.VERTICAL, command=txtbox.yview)
         scrollbar.grid(row=0, column=1, sticky='nsew')
@@ -454,10 +602,10 @@ class Application:
         txtbox.config(state=tk.DISABLED)
 
         # footer - copyright
-        frame = tk.Frame(panedwindow, width=380, height=20)
+        frame = self.Frame(panedwindow, width=380, height=20)
         panedwindow.add(frame, weight=1)
 
-        footer = tk.Label(frame, text=Data.copyright_text)
+        footer = self.Label(frame, text=Data.copyright_text)
         footer.pack(side=tk.LEFT)
 
         set_modal_dialog(about)
@@ -465,20 +613,20 @@ class Application:
     def callback_preferences_settings(self):
         """Callback for Menu Preferences > Settings"""
 
-        is_macos = platform.system() == 'Darwin'
-        is_linux = platform.system() == 'Linux'
-
         settings = tk.Toplevel(self.root)
         self.set_title(node=settings, title='Settings')
-        width = 540 if is_macos else 490 if is_linux else 400
+        width = 540 if self.is_macos else 490 if self.is_linux else 400
         height = 370
         x, y = get_relative_center_location(self.root, width, height)
         settings.geometry('{}x{}+{}+{}'.format(width, height, x, y))
         settings.resizable(False, False)
 
+        top_frame = self.Frame(settings)
+        top_frame.pack(fill=tk.BOTH, expand=True)
+
         # Settings - Pattern Arguments
-        lframe_pattern_args = ttk.LabelFrame(
-            settings, height=80, width=380,
+        lframe_pattern_args = self.LabelFrame(
+            top_frame, height=80, width=380,
             text='Pattern Arguments'
         )
         lframe_pattern_args.grid(row=0, column=0, padx=10, pady=10, sticky=tk.W)
@@ -490,94 +638,94 @@ class Application:
             ['appended_ws', self.appended_ws_var, 1, 1]
         ]
         for text, variable, row, column in lst:
-            tk.Checkbutton(
+            self.CheckBox(
                 lframe_pattern_args, text=text, variable=variable,
                 onvalue=True, offvalue=False
             ).grid(row=row, column=column, padx=2, pady=2, sticky=tk.W)
 
         # Settings - Builder Arguments
-        lframe_builder_args = ttk.LabelFrame(
-            settings, height=280, width=380,
+        lframe_builder_args = self.LabelFrame(
+            top_frame, height=280, width=380,
             text='Builder Arguments'
         )
         # lframe_builder_args.place(x=10, y=95)
         lframe_builder_args.grid(row=1, column=0, padx=10, pady=(0, 10), sticky=tk.W)
 
-        pady = 0 if is_macos else 3
+        pady = 0 if self.is_macos else 3
 
-        ttk.Label(
+        self.Label(
             lframe_builder_args, text='max_words'
         ).grid(row=0, column=0, columnspan=2, padx=2, pady=(5, pady), sticky=tk.W)
 
-        ttk.Entry(
+        self.TextBox(
             lframe_builder_args, width=5, textvariable=self.max_words_var
         ).grid(row=0, column=2, padx=2, pady=(5, pady), sticky=tk.W)
 
-        tk.Checkbutton(
+        self.CheckBox(
             lframe_builder_args, text='is_minimal',
             variable=self.is_minimal_var, onvalue=True, offvalue=False
         ).grid(row=0, column=3, columnspan=3, padx=2, pady=(5, pady), sticky=tk.W)
 
-        ttk.Label(
+        self.Label(
             lframe_builder_args, text='test_name'
         ).grid(row=1, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
-        ttk.Entry(
+        self.TextBox(
             lframe_builder_args, width=45,
             textvariable=self.test_name_var
         ).grid(row=1, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(
+        self.Label(
             lframe_builder_args, text='test_cls_name'
         ).grid(row=2, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
-        ttk.Entry(
+        self.TextBox(
             lframe_builder_args, width=45,
             textvariable=self.test_cls_name_var
         ).grid(row=2, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(
+        self.Label(
             lframe_builder_args, text='filename'
         ).grid(row=3, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
-        ttk.Entry(
+        self.TextBox(
             lframe_builder_args, width=45,
             textvariable=self.filename_var
         ).grid(row=3, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(
+        self.Label(
             lframe_builder_args, text='author'
         ).grid(row=4, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
-        ttk.Entry(
+        self.TextBox(
             lframe_builder_args, width=45,
             textvariable=self.author_var
         ).grid(row=4, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(
+        self.Label(
             lframe_builder_args, text='email'
         ).grid(row=5, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
-        ttk.Entry(
+        self.TextBox(
             lframe_builder_args, width=45,
             textvariable=self.email_var
         ).grid(row=5, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(
+        self.Label(
             lframe_builder_args, text='company'
         ).grid(row=6, column=0, columnspan=2, padx=2, pady=(pady, 10), sticky=tk.W)
-        ttk.Entry(
+        self.TextBox(
             lframe_builder_args, width=45,
             textvariable=self.company_var
         ).grid(row=6, column=2, columnspan=4, padx=2, pady=(pady, 10), sticky=tk.W)
 
         # OK and Default buttons
-        frame = tk.Frame(
-            settings, height=20, width=380
+        frame = self.Frame(
+            top_frame, height=20, width=380
         )
         frame.grid(row=2, column=0, padx=10, pady=10, sticky=tk.E+tk.S)
 
-        ttk.Button(
+        self.Button(
             frame, text='Default',
             command=lambda: self.set_default_setting(),
         ).grid(row=0, column=6, padx=1, pady=1, sticky=tk.E)
 
-        ttk.Button(
+        self.Button(
             frame, text='OK',
             command=lambda: settings.destroy(),
         ).grid(row=0, column=7, padx=1, pady=1, sticky=tk.E)
@@ -587,18 +735,19 @@ class Application:
     def callback_preferences_system_reference(self):
         """Callback for Menu Preferences > System References"""
 
-        is_macos = platform.system() == 'Darwin'
-
         sys_ref = tk.Toplevel(self.root)
         self.set_title(node=sys_ref, title='System References')
         width, height = 600, 500
         x, y = get_relative_center_location(self.root, width, height)
         sys_ref.geometry('{}x{}+{}+{}'.format(width, height, x, y))
 
-        panedwindow = ttk.Panedwindow(sys_ref, orient=tk.VERTICAL)
+        top_frame = self.Frame(sys_ref)
+        top_frame.pack(fill=tk.BOTH, expand=True)
+
+        panedwindow = self.PanedWindow(top_frame, orient=tk.VERTICAL)
         panedwindow.pack(fill=tk.BOTH, expand=True)
 
-        text_frame = ttk.Frame(
+        text_frame = self.Frame(
             panedwindow, width=500, height=300, relief=tk.RIDGE
         )
         panedwindow.add(text_frame, weight=9)
@@ -606,7 +755,7 @@ class Application:
         text_frame.rowconfigure(0, weight=1)
         text_frame.columnconfigure(0, weight=1)
 
-        textarea = tk.Text(text_frame, width=20, height=5, wrap='none')
+        textarea = self.TextArea(text_frame, width=20, height=5, wrap='none')
         with open(REF.sys_ref_loc) as stream:
             content = stream.read()
             self.set_textarea(textarea, content)
@@ -625,10 +774,10 @@ class Application:
             state=tk.DISABLED
         )
 
-        padx, pady = (0, 0) if is_macos else (2, 2)
-        ttk.Button(sys_ref, text='OK',
-                   command=lambda: sys_ref.destroy()
-                   ).pack(side=tk.RIGHT, padx=padx, pady=pady)
+        padx, pady = (0, 0) if self.is_macos else (2, 2)
+        self.Button(top_frame, text='OK',
+                    command=lambda: sys_ref.destroy()
+                    ).pack(side=tk.RIGHT, padx=padx, pady=pady)
 
         set_modal_dialog(sys_ref)
 
@@ -680,8 +829,6 @@ class Application:
             node.delete("1.0", "end")
             node.insert(tk.INSERT, new_content_)
 
-        is_macos = platform.system() == 'Darwin'
-
         fn = REF.user_ref_loc
         file_obj = Path(fn)
         if not file_obj.exists():
@@ -700,10 +847,13 @@ class Application:
         x, y = get_relative_center_location(self.root, width, height)
         user_ref.geometry('{}x{}+{}+{}'.format(width, height, x, y))
 
-        panedwindow = ttk.Panedwindow(user_ref, orient=tk.VERTICAL)
+        top_frame = self.Frame(user_ref)
+        top_frame.pack(fill=tk.BOTH, expand=True)
+
+        panedwindow = self.PanedWindow(top_frame, orient=tk.VERTICAL)
         panedwindow.pack(fill=tk.BOTH, expand=True)
 
-        text_frame = ttk.Frame(
+        text_frame = self.Frame(
             panedwindow, width=500, height=300, relief=tk.RIDGE
         )
         panedwindow.add(text_frame, weight=9)
@@ -711,7 +861,7 @@ class Application:
         text_frame.rowconfigure(0, weight=1)
         text_frame.columnconfigure(0, weight=1)
 
-        textarea = tk.Text(text_frame, width=20, height=5, wrap='none')
+        textarea = self.TextArea(text_frame, width=20, height=5, wrap='none')
 
         with open(REF.user_ref_loc) as stream:
             content = stream.read()
@@ -730,24 +880,24 @@ class Application:
             yscrollcommand=vscrollbar.set, xscrollcommand=hscrollbar.set,
         )
 
-        padx, pady = (0, 0) if is_macos else (2, 2)
+        padx, pady = (0, 0) if self.is_macos else (2, 2)
 
-        ttk.Button(
-            user_ref, text='Save', command=lambda: save(textarea)
+        self.Button(
+            top_frame, text='Save', command=lambda: save(textarea)
         ).pack(side=tk.RIGHT, padx=padx, pady=pady)
 
-        ttk.Button(
-            user_ref, text='Close', command=lambda: user_ref.destroy()
+        self.Button(
+            top_frame, text='Close', command=lambda: user_ref.destroy()
         ).pack(side=tk.RIGHT, padx=padx, pady=pady)
 
-        tk.Label(user_ref, text='Name:').pack(side=tk.LEFT, padx=padx, pady=pady)
+        self.Label(top_frame, text='Name:').pack(side=tk.LEFT, padx=padx, pady=pady)
 
-        ttk.Entry(
-            user_ref, width=25, textvariable=self.new_pattern_name_var
+        self.TextBox(
+            top_frame, width=25, textvariable=self.new_pattern_name_var
         ).pack(side=tk.LEFT, padx=padx, pady=pady)
 
-        ttk.Button(
-            user_ref, text='Insert',
+        self.Button(
+            top_frame, text='Insert',
             command=lambda: insert(self.new_pattern_name_var, textarea),
         ).pack(side=tk.LEFT, padx=padx, pady=pady)
 
@@ -793,16 +943,16 @@ class Application:
 
     def build_frame(self):
         """Build layout for regex GUI."""
-        self.panedwindow = ttk.Panedwindow(self.root, orient=tk.VERTICAL)
+        self.panedwindow = self.PanedWindow(self.root, orient=tk.VERTICAL)
         self.panedwindow.pack(fill=tk.BOTH, expand=True, padx=2, pady=2)
 
-        self.text_frame = ttk.Frame(
+        self.text_frame = self.Frame(
             self.panedwindow, width=600, height=300, relief=tk.RIDGE
         )
-        self.entry_frame = ttk.Frame(
+        self.entry_frame = self.Frame(
             self.panedwindow, width=600, height=40, relief=tk.RIDGE
         )
-        self.result_frame = ttk.Frame(
+        self.result_frame = self.Frame(
             self.panedwindow, width=600, height=350, relief=tk.RIDGE
         )
         self.panedwindow.add(self.text_frame, weight=4)
@@ -814,7 +964,7 @@ class Application:
 
         self.text_frame.rowconfigure(0, weight=1)
         self.text_frame.columnconfigure(0, weight=1)
-        self.textarea = tk.Text(self.text_frame, width=20, height=5, wrap='none')
+        self.textarea = self.TextArea(self.text_frame, width=20, height=5, wrap='none')
         self.textarea.grid(row=0, column=0, sticky='nswe')
         vscrollbar = ttk.Scrollbar(
             self.text_frame, orient=tk.VERTICAL, command=self.textarea.yview
@@ -839,31 +989,41 @@ class Application:
                 )
                 return
 
-            try:
-                kwargs = self.get_pattern_args()
-                factory = RegexBuilder(user_data=user_data, **kwargs)
-                factory.build()
-
-                patterns = factory.patterns
-                total = len(patterns)
-                if total >= 1:
-                    if total == 1:
-                        result = 'pattern = r{}'.format(enclose_string(patterns[0]))
-                    else:
-                        lst = []
-                        fmt = 'pattern{} = r{}'
-                        for index, pattern in enumerate(patterns, 1):
-                            lst.append(fmt.format(index, enclose_string(pattern)))
-                        result = '\n'.join(lst)
+            if self.is_pattern_builder_app:
+                try:
+                    kwargs = self.get_pattern_builder_args()
+                    pattern = PatternBuilder(user_data, **kwargs)
+                    result = 'pattern = r{}'.format(enclose_string(pattern))
                     self.set_textarea(self.result_textarea, result)
-                    self.save_as_btn.config(state=tk.NORMAL)
-                    self.copy_text_btn.config(state=tk.NORMAL)
-                else:
-                    error = 'Something wrong with RegexBuilder.  Please report bug.'
+                except Exception as ex:
+                    error = '{}: {}'.format(type(ex).__name__, ex)
+                    create_msgbox(title='PatternBuilder Error', error=error)
+            else:
+                try:
+                    kwargs = self.get_pattern_args()
+                    factory = RegexBuilder(user_data=user_data, **kwargs)
+                    factory.build()
+
+                    patterns = factory.patterns
+                    total = len(patterns)
+                    if total >= 1:
+                        if total == 1:
+                            result = 'pattern = r{}'.format(enclose_string(patterns[0]))
+                        else:
+                            lst = []
+                            fmt = 'pattern{} = r{}'
+                            for index, pattern in enumerate(patterns, 1):
+                                lst.append(fmt.format(index, enclose_string(pattern)))
+                            result = '\n'.join(lst)
+                        self.set_textarea(self.result_textarea, result)
+                        self.save_as_btn.config(state=tk.NORMAL)
+                        self.copy_text_btn.config(state=tk.NORMAL)
+                    else:
+                        error = 'Something wrong with RegexBuilder.  Please report bug.'
+                        create_msgbox(title='RegexBuilder Error', error=error)
+                except Exception as ex:
+                    error = '{}: {}'.format(type(ex).__name__, ex)
                     create_msgbox(title='RegexBuilder Error', error=error)
-            except Exception as ex:
-                error = '{}: {}'.format(type(ex).__name__, ex)
-                create_msgbox(title='RegexBuilder Error', error=error)
 
         def callback_save_as_btn():
             filename = filedialog.asksaveasfilename()
@@ -893,7 +1053,8 @@ class Application:
                 if not data:
                     return
 
-                self.test_data = data
+                if not self.is_pattern_builder_app:
+                    self.test_data = data
 
                 title = '<<PASTE - Clipboard>>'
                 self.set_textarea(self.textarea, data, title=title)
@@ -1002,6 +1163,12 @@ class Application:
                 error = '{}: {}'.format(type(ex).__name__, ex)
                 create_msgbox(title='RegexBuilder Error', error=error)
 
+        def callback_builder_chkbox():
+            if self.is_pattern_builder_app:
+                self.shift_to_pattern_builder_app()
+            else:
+                self.shift_to_regex_builder_app()
+
         # def callback_rf_btn():
         #     create_msgbox(
         #         title='Robotframework feature',
@@ -1009,69 +1176,103 @@ class Application:
         #     )
 
         # radio buttons
-        self.line_radio_btn = tk.Radiobutton(
+        self.line_radio_btn = self.RadioButton(
             self.entry_frame, text='line',
             variable=self.radio_line_or_multiline_btn_var,
             value='line'
         )
         self.line_radio_btn.grid(row=0, column=0, padx=(4, 0))
 
-        self.multiline_radio_btn = tk.Radiobutton(
+        self.multiline_radio_btn = self.RadioButton(
             self.entry_frame, text='multiline',
             variable=self.radio_line_or_multiline_btn_var,
             value='multiline'
         )
         self.multiline_radio_btn.grid(row=0, column=1, padx=2)
 
+        btn_width = 5.5 if self.is_macos else 8
         # open button
-        open_file_btn = ttk.Button(self.entry_frame, text='Open',
-                                   command=self.callback_file_open)
+        open_file_btn = self.Button(self.entry_frame, text='Open',
+                                    command=self.callback_file_open,
+                                    width=btn_width)
         open_file_btn.grid(row=0, column=2, pady=2)
 
         # Save As button
-        self.save_as_btn = ttk.Button(self.entry_frame, text='Save As',
-                                      command=callback_save_as_btn)
+        self.save_as_btn = self.Button(self.entry_frame, text='Save As',
+                                       command=callback_save_as_btn,
+                                       width=btn_width)
         self.save_as_btn.grid(row=0, column=3)
         self.save_as_btn.config(state=tk.DISABLED)
 
         # copy button
-        self.copy_text_btn = ttk.Button(self.entry_frame, text='Copy',
-                                        command=callback_copy_text_btn)
+        self.copy_text_btn = self.Button(self.entry_frame, text='Copy',
+                                         command=callback_copy_text_btn,
+                                         width=btn_width)
         self.copy_text_btn.grid(row=0, column=4)
         self.copy_text_btn.config(state=tk.DISABLED)
 
         # paste button
         paste_text_btn = ttk.Button(self.entry_frame, text='Paste',
-                                    command=callback_paste_text_btn)
+                                    command=callback_paste_text_btn,
+                                    width=btn_width)
         paste_text_btn.grid(row=0, column=5)
 
         # clear button
-        clear_text_btn = ttk.Button(self.entry_frame, text='Clear',
-                                    command=callback_clear_text_btn)
+        clear_text_btn = self.Button(self.entry_frame, text='Clear',
+                                     command=callback_clear_text_btn,
+                                     width=btn_width)
         clear_text_btn.grid(row=0, column=6)
 
         # build button
-        build_btn = ttk.Button(self.entry_frame, text='Build',
-                               command=callback_build_btn)
+        build_btn = self.Button(self.entry_frame, text='Build',
+                                command=callback_build_btn,
+                                width=btn_width)
         build_btn.grid(row=0, column=7)
 
         # snippet button
-        snippet_btn = ttk.Button(self.entry_frame, text='Snippet',
-                                 command=callback_snippet_btn)
-        snippet_btn.grid(row=0, column=8)
+        self.snippet_btn = self.Button(self.entry_frame, text='Snippet',
+                                       command=callback_snippet_btn,
+                                       width=btn_width)
+        self.snippet_btn.grid(row=0, column=8)
 
         # unittest button
-        unittest_btn = ttk.Button(self.entry_frame, text='Unittest',
-                                  command=callback_unittest_btn)
-        unittest_btn.grid(row=0, column=9)
+        self.unittest_btn = self.Button(self.entry_frame, text='Unittest',
+                                        command=callback_unittest_btn,
+                                        width=btn_width)
+        self.unittest_btn.grid(row=0, column=9)
 
         # pytest button
-        pytest_btn = ttk.Button(self.entry_frame, text='Pytest',
-                                command=callback_pytest_btn)
-        pytest_btn.grid(row=0, column=10)
+        self.pytest_btn = self.Button(self.entry_frame, text='Pytest',
+                                      command=callback_pytest_btn,
+                                      width=btn_width)
+        self.pytest_btn.grid(row=0, column=10)
+
+        # builder checkbox
+        builder_chkbox = self.CheckBox(
+            self.entry_frame, text='Builder', variable=self.builder_chkbox_var,
+            onvalue=True, offvalue=False,
+            command=callback_builder_chkbox
+        )
+        builder_chkbox.grid(row=0, column=11)
+
+        self.var_name_frame = self.Frame(self.entry_frame)
+        self.Label(self.var_name_frame, text='var_name').pack(padx=(10, 4), side=tk.LEFT)
+        self.TextBox(
+            self.var_name_frame, width=12, textvariable=self.var_name_var
+        ).pack(side=tk.LEFT)
+
+        self.word_bound_frame = self.Frame(self.entry_frame)
+        self.Label(self.word_bound_frame, text='word_bound').pack(padx=(10, 4), side=tk.LEFT)
+        ttk.Combobox(
+            self.word_bound_frame,
+            state='readonly',
+            values=['both', 'left', 'right', 'none'],
+            textvariable=self.word_bound_var,
+            width=6
+        ).pack(side=tk.LEFT)
 
         # Robotframework button
-        # rf_btn = ttk.Button(self.entry_frame, text='RF',
+        # rf_btn = self.Button(self.entry_frame, text='RF',
         #                     command=callback_rf_btn, width=4)
         # rf_btn.grid(row=0, column=11)
 
@@ -1079,7 +1280,7 @@ class Application:
         """Build result text"""
         self.result_frame.rowconfigure(0, weight=1)
         self.result_frame.columnconfigure(0, weight=1)
-        self.result_textarea = tk.Text(
+        self.result_textarea = self.TextArea(
             self.result_frame, width=20, height=5, wrap='none'
         )
         self.result_textarea.grid(row=0, column=0, sticky='nswe')
